#ifndef _EFL_VG_ROOT_NODE_EO_H_
#define _EFL_VG_ROOT_NODE_EO_H_

#ifndef _EFL_VG_ROOT_NODE_EO_CLASS_TYPE
#define _EFL_VG_ROOT_NODE_EO_CLASS_TYPE

typedef Eo Efl_VG_Root_Node;

#endif

#ifndef _EFL_VG_ROOT_NODE_EO_TYPES
#define _EFL_VG_ROOT_NODE_EO_TYPES


#endif
/** Efl vector graphics root node class
 *
 * @ingroup Efl_VG_Root_Node
 */
#define EFL_VG_ROOT_NODE_CLASS efl_vg_root_node_class_get()

EWAPI const Efl_Class *efl_vg_root_node_class_get(void);

#endif
